==> org-lsst-ccs-subsystem-refrig-buses-4.4.3-sources.jar: org/lsst/ccs/subsystem/refrig/data/ThermalState.java <==
package org.lsst.ccs.subsystem.refrig.data;

import java.io.Serializable;
import java.util.Arrays;
import org.lsst.ccs.bus.annotations.SkipEncoding;
import org.lsst.ccs.subsystem.refrig.constants.SwitchState;
import org.lsst.ccs.subsystem.refrig.constants.TrimHeaterOpState;
import org.lsst.ccs.subsystem.refrig.constants.TrimHeaterState;

/**
 *  Contains the state of the thermal system
 *
 *  @author Owen Saxton
 */
@SkipEncoding
public class ThermalState implements Serializable {

    public static final String KEY = "ThermalState";

    public static final int
        TRIM_HEATER_CRYO     = 0,
        TRIM_HEATER_COLD     = 1,
        TRIM_HEATER_COLD_MYE = 2,
        TRIM_HEATER_COLD_PYE = 3,
        TRIM_HEATER_COLD_C   = 4,
        TRIM_HEATER_COLD_MYC = 5,
        TRIM_HEATER_COLD_PYC = 6,
        NUM_TRIM_HEATERS     = 7;

    private int tickMillis;         // Data status update period (ms)
    private Integer[] trimHeaters = new Integer[0];
    private SwitchState bulkPowerState = SwitchState.OFFLINE;
    private final TrimHeaterOpState[] trimHeaterOpState = new TrimHeaterOpState[NUM_TRIM_HEATERS];  // Trim heater operation state
    private final TrimHeaterState[] trimHeaterState = new TrimHeaterState[NUM_TRIM_HEATERS];  // Trim heater state
    private final double[] trimHeaterPower = new double[NUM_TRIM_HEATERS];          // Trim heater power set point
    private final double[] plateTemperature = new double[NUM_TRIM_HEATERS];         // Plate temperature set point

    public ThermalState() {
        Arrays.fill(trimHeaterOpState, TrimHeaterOpState.OFF);
        Arrays.fill(trimHeaterState, TrimHeaterState.OFFLINE);
    }

    public void setTickMillis(int value) {
        tickMillis = value;
    }

    public int getTickMillis() {
        return tickMillis;
    }

    public void setTrimHeaters(Integer[] value) {
        trimHeaters = value;
    }

    public Integer[] getTrimHeaters() {
        return trimHeaters;
    }

    public void setBulkPowerState(SwitchState state) {
       bulkPowerState = state; 
    }

    public SwitchState getBulkPowerState() {
        return bulkPowerState;
    }

    public void setTrimHeaterOpState(int heater, TrimHeaterOpState state) {
        trimHeaterOpState[heater] = state;
    }

    public TrimHeaterOpState getTrimHeaterOpState(int heater) {
        return trimHeaterOpState[heater];
    }

    public void setTrimHeaterState(int heater, TrimHeaterState state) {
        trimHeaterState[heater] = state;
    }

    public TrimHeaterState getTrimHeaterState(int heater) {
        return trimHeaterState[heater];
    }

    public void setTrimHeaterPower(int heater, double value) {
        trimHeaterPower[heater] = value;
    }

    public double getTrimHeaterPower(int heater) {
        return trimHeaterPower[heater];
    }

    public void setPlateTemperature(int heater, double value) {
        plateTemperature[heater] = value;
    }

    public double getPlateTemperature(int heater) {
        return plateTemperature[heater];
    }

    private static final long serialVersionUID = 5207828928167279057L;
}

==> org-lsst-ccs-subsystem-refrig-buses-4.4.26-sources.jar: org/lsst/ccs/subsystem/refrig/data/ThermalState.java <==
package org.lsst.ccs.subsystem.refrig.data;

import java.io.Serializable;
import java.util.Arrays;
import org.lsst.ccs.bus.annotations.SkipEncoding;
import org.lsst.ccs.subsystem.refrig.constants.SwitchState;
import org.lsst.ccs.subsystem.refrig.constants.TrimHeaterOpState;
import org.lsst.ccs.subsystem.refrig.constants.TrimHeaterState;
import org.lsst.ccs.subsystem.refrig.constants.TrimHeaters;

/**
 *  Contains the state of the thermal system
 *
 *  @author Owen Saxton
 */
@SkipEncoding
public class ThermalState implements Serializable {

    public static final String KEY = "ThermalState";

    private int tickMillis;         // Data status update period (ms)
    private Integer[] trimHeaters = new Integer[0];
    private SwitchState bulkPowerState = SwitchState.OFFLINE;
    private final TrimHeaterOpState[] trimHeaterOpState = new TrimHeaterOpState[TrimHeaters.NUM_TRIM_HEATERS];  // Trim heater operation state
    private final TrimHeaterState[] trimHeaterState = new TrimHeaterState[TrimHeaters.NUM_TRIM_HEATERS];  // Trim heater state
    private final double[] trimHeaterPower = new double[TrimHeaters.NUM_TRIM_HEATERS];          // Trim heater power set point
    private final double[] plateTemperature = new double[TrimHeaters.NUM_TRIM_HEATERS];         // Plate temperature set point

    public ThermalState() {
        Arrays.fill(trimHeaterOpState, TrimHeaterOpState.OFF);
        Arrays.fill(trimHeaterState, TrimHeaterState.OFFLINE);
    }

    public void setTickMillis(int value) {
        tickMillis = value;
    }

    public int getTickMillis() {
        return tickMillis;
    }

    public void setTrimHeaters(Integer[] value) {
        trimHeaters = value;
    }

    public Integer[] getTrimHeaters() {
        return trimHeaters;
    }

    public void setBulkPowerState(SwitchState state) {
       bulkPowerState = state; 
    }

    public SwitchState getBulkPowerState() {
        return bulkPowerState;
    }

    public void setTrimHeaterOpState(int heater, TrimHeaterOpState state) {
        trimHeaterOpState[heater] = state;
    }

    public TrimHeaterOpState getTrimHeaterOpState(int heater) {
        return trimHeaterOpState[heater];
    }

    public void setTrimHeaterState(int heater, TrimHeaterState state) {
        trimHeaterState[heater] = state;
    }

    public TrimHeaterState getTrimHeaterState(int heater) {
        return trimHeaterState[heater];
    }

    public void setTrimHeaterPower(int heater, double value) {
        trimHeaterPower[heater] = value;
    }

    public double getTrimHeaterPower(int heater) {
        return trimHeaterPower[heater];
    }

    public void setPlateTemperature(int heater, double value) {
        plateTemperature[heater] = value;
    }

    public double getPlateTemperature(int heater) {
        return plateTemperature[heater];
    }

    private static final long serialVersionUID = 5207828928167279057L;
}
